@@ -261,6 +261,7 @@ static int copy_obu(struct mbuf *mb_bs, const uint8_t *buf, size_t size)
 		.pos = 0,
 		.end = size
 	};
+	char debug[512] = "";
 	bool has_size = true;
 
 	int err = av1_obu_decode(&hdr, &wrap);
@@ -270,6 +271,9 @@ static int copy_obu(struct mbuf *mb_bs, const uint8_t *buf, size_t size)
 		return err;
 	}
 
+	re_snprintf(debug, sizeof(debug), "%H\n", av1_obu_print, &hdr);
+	ASSERT_TRUE(str_isset(debug));
+
 	switch (hdr.type) {
 
 	case AV1_OBU_SEQUENCE_HEADER:
@@ -303,7 +307,8 @@ static int copy_obu(struct mbuf *mb_bs, const uint8_t *buf, size_t size)
 		return EPROTO;
 	}
 
-	return 0;
+ out:
+	return err;
 }
 
 
