@@ -68,6 +68,7 @@ static const struct test tests[] = {
 	TEST(test_btrace),
 	TEST(test_conf),
 	TEST(test_crc32),
+	TEST(test_dbg),
 	TEST(test_dd),
 	TEST(test_dns_dname),
 	TEST(test_dns_hdr),
@@ -84,6 +85,7 @@ static const struct test tests[] = {
 	TEST(test_fmt_human_time),
 	TEST(test_fmt_param),
 	TEST(test_fmt_pl),
+	TEST(test_fmt_pl_alloc_dup),
 	TEST(test_fmt_pl_alloc_str),
 	TEST(test_fmt_pl_float),
 	TEST(test_fmt_pl_i32),
